'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = shallow;

var _vue = require('vue');

var _vue2 = _interopRequireDefault(_vue);

var _lodash = require('lodash');

var _mount = require('./mount');

var _mount2 = _interopRequireDefault(_mount);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var LIFECYCLE_HOOKS = ['beforeCreate', 'created', 'beforeMount', 'mounted', 'beforeUpdate', 'updated', 'beforeDestroy', 'destroyed', 'activated', 'deactivated'];

function stubLifeCycleEvents(component) {
  LIFECYCLE_HOOKS.forEach(function (hook) {
    component[hook] = function () {};
  });
}

function replaceComponents(component) {
  Object.keys(component.components).forEach(function (c) {
    delete component.components[c]._Ctor;
    component.components[c] = {
      attrs: component.components[c].attrs,
      name: component.components[c].name,
      on: component.components[c].on,
      key: component.components[c].key,
      ref: component.components[c].ref,
      props: component.components[c].props,
      domProps: component.components[c].domProps,
      class: component.components[c].class,
      render: function render() {}
    };
    _vue2.default.config.ignoredElements.push(c);
    stubLifeCycleEvents(component.components[c]);
  });
}

function shallow(component, options) {
  var clonedComponent = (0, _lodash.cloneDeep)(component);

  if (clonedComponent.components) {
    replaceComponents(clonedComponent);
  }

  return (0, _mount2.default)(clonedComponent, options);
}